@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -22,6 +22,7 @@
 #include "polymake/hash_map"
 #include "polymake/IncidenceMatrix.h"
 #include "polymake/linalg.h"
+#include "polymake/fan/prune_polyhedral_complex.h"
 
 namespace polymake { namespace fan {
 
@@ -117,20 +118,62 @@ BigObject common_refinement(BigObject f1, BigObject f2)
       }
    }
 
+   BigObject result("PolyhedralFan", mlist<Coord>());
+   result.take("COMPLETE") << complete;
+   result.take("FAN_AMBIENT_DIM") << ambient_dim;
+   result.take("LINEALITY_DIM") << lineality_space.rows();
    if (complete) {
-      return BigObject("PolyhedralFan", "COMPLETE", complete, "FAN_AMBIENT_DIM", ambient_dim, "LINEALITY_DIM", lineality_space.rows(),
-                       "FAN_DIM", d, "RAYS", rays, "MAXIMAL_CONES", new_max_cones, "LINEALITY_SPACE", lineality_space);
+      result.take("FAN_DIM") << d;
+      result.take("RAYS") << rays;
+      result.take("MAXIMAL_CONES") << new_max_cones;
+      result.take("LINEALITY_SPACE") << lineality_space;
    } else {
-      return BigObject("PolyhedralFan", "COMPLETE", complete, "FAN_AMBIENT_DIM", ambient_dim, "LINEALITY_DIM", lineality_space.rows(),
-                       "INPUT_RAYS", rays, "INPUT_CONES", new_max_cones, "INPUT_LINEALITY", lineality_space);
+      result.take("INPUT_RAYS") << rays;
+      result.take("INPUT_CONES") << new_max_cones;
+      result.take("INPUT_LINEALITY") << lineality_space;
+   }
+   
+   if(f1.isa("PolyhedralComplex")){
+      return prune_polyhedral_complex<Coord>(result);
+   } else {
+      return result;
    }
 }
 
 UserFunctionTemplate4perl("# @category Producing a fan"
-                          "# Computes the common refinement of two fans."
+                          "# Computes the common refinement of two fans. This is the fan made of"
+                          "# all intersections of cones of the first fan with cones of the"
+                          "# second fan. Note that the support of the result is the intersection"
+                          "# of the supports of the input fans."
                           "# @param PolyhedralFan f1"
                           "# @param PolyhedralFan f2"
-                          "# @return PolyhedralFan",
+                          "# @return PolyhedralFan"
+                          "# @example [prefer cdd] Two two-dimensional fans with different support"
+                          "# > $s = simplex(2);"
+                          "# > $c = new Polytope(POINTS=>[[1,0,0],[0,-1,0],[0,0,-1]]);"
+                          "# > $f1 = normal_fan($s);"
+                          "# > $f2 = normal_fan($c);"
+                          "# > print $f1->RAYS;"
+                          "# | -1 -1"
+                          "# | 1 0"
+                          "# | 0 1"
+                          "# > print $f1->MAXIMAL_CONES;"
+                          "# | {1 2}"
+                          "# | {0 2}"
+                          "# | {0 1}"
+                          "# > print $f2->RAYS;"
+                          "# | -1 0"
+                          "# | 0 -1"
+                          "# > print $f2->MAXIMAL_CONES;"
+                          "# | {0 1}"
+                          "# > $cc = common_refinement($f1,$f2);"
+                          "# > print $cc->RAYS;"
+                          "# | -1 -1"
+                          "# | -1 0"
+                          "# | 0 -1"
+                          "# > print $cc->MAXIMAL_CONES;"
+                          "# | {0 1}"
+                          "# | {0 2}",
                           "common_refinement<Coord>(PolyhedralFan<Coord>,PolyhedralFan<Coord>)");
 } }
 
