@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -15,8 +15,7 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_GRAPH_DIAMETER_H
-#define POLYMAKE_GRAPH_DIAMETER_H
+#pragma once
 
 #include "polymake/GenericGraph.h"
 #include "polymake/graph/graph_iterators.h"
@@ -74,7 +73,6 @@ Int diameter(const GenericGraph<TGraph>& G)
 
 } }
 
-#endif // POLYMAKE_GRAPH_DIAMETER_H
 
 // Local Variables:
 // mode:C++
