@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -21,13 +22,13 @@
 
 namespace polymake { namespace matroid {
 
-void bases_from_lof(perl::Object M)
+void bases_from_lof(BigObject M)
 {
-   const perl::Object LF_obj = M.give("LATTICE_OF_FLATS");
-   const Lattice<BasicDecoration, Sequential> LF(LF_obj);
-   const int n = M.give("N_ELEMENTS");
-   const Array<Set<int> > bases = bases_from_lof_impl(LF, n);
-	int LF_dim = LF.rank();
+   const BigObject LF_obj = M.give("LATTICE_OF_FLATS");
+   const graph::Lattice<graph::lattice::BasicDecoration, graph::lattice::Sequential> LF(LF_obj);
+   const Int n = M.give("N_ELEMENTS");
+   const Array<Set<Int>> bases = bases_from_lof_impl(LF, n);
+   Int LF_dim = LF.rank();
    M.take("RANK") << LF_dim; //Hasse diagram has a shift for lattice with just one node
    M.take("BASES") << bases;
    M.take("N_BASES") << bases.size();
@@ -35,7 +36,6 @@ void bases_from_lof(perl::Object M)
 
 Function4perl(&bases_from_lof, "bases_from_lof(Matroid)");
 
-
 } }
 
 // Local Variables:
