@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -15,8 +15,7 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_POLYTOPE_HYPERSIMPLEX_H
-#define POLYMAKE_POLYTOPE_HYPERSIMPLEX_H
+#pragma once
 
 #include "polymake/client.h"
 
@@ -26,7 +25,6 @@ BigObject hypersimplex(Int d, Int k, OptionSet options);
 
 } }
 
-#endif // POLYMAKE_POLYTOPE_HYPERSIMPLEX_H
 
 // Local Variables:
 // mode:C++
