@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -15,8 +15,7 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_POLYTOPE_TRANSFORM_H
-#define POLYMAKE_POLYTOPE_TRANSFORM_H
+#pragma once
 
 #include "polymake/client.h"
 #include "polymake/IncidenceMatrix.h"
@@ -88,7 +87,6 @@ BigObject transform(BigObject p_in, const GenericMatrix<TransMatrix>& tau,
 
 } } // end namespace polymake
 
-#endif // POLYMAKE_POLYTOPE_TRANSFORM_H
 
 // Local Variables:
 // mode:C++
