@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -22,30 +23,29 @@
 namespace polymake { namespace polytope {
 namespace {
 
-typedef Map<int,int> face_map_type;
-typedef graph::Lattice<graph::lattice::BasicDecoration, graph::lattice::Sequential>::nodes_of_rank_type nodes_list;
+using face_map_type = Map<Int, Int>;
 
-template <typename IM> inline
-face_map_type count(const GenericIncidenceMatrix<IM>& adj, const nodes_list& face_indices)
+template <typename IM, typename NodeList>
+face_map_type count(const GenericIncidenceMatrix<IM>& adj, const NodeList& face_indices)
 {
    face_map_type face_map;
 
-   for (auto f=entire(face_indices); !f.at_end(); ++f)
-      face_map[adj.col(*f).size()]++;
+   for (const auto f : face_indices)
+      ++face_map[adj.col(f).size()];
    return face_map;
 }
 }
 
-face_map_type two_face_sizes(perl::Object p)
+face_map_type two_face_sizes(BigObject p)
 {
    const graph::Lattice<graph::lattice::BasicDecoration, graph::lattice::Sequential> HD(p);
    return count(adjacency_matrix(HD.graph()), HD.nodes_of_rank(3));
 }
 
-face_map_type subridge_sizes(perl::Object p)
+face_map_type subridge_sizes(BigObject p)
 {
    const graph::Lattice<graph::lattice::BasicDecoration, graph::lattice::Sequential> HD(p);
-   int top_rank = HD.rank();
+   Int top_rank = HD.rank();
    return count(T(adjacency_matrix(HD.graph())), HD.nodes_of_rank(top_rank-3));
 }
 
