@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -21,13 +21,14 @@
 #include "polymake/Matrix.h"
 #include "polymake/IncidenceMatrix.h"
 #include "polymake/Set.h"
-#include "polymake/PowerSet.h"
+#include "polymake/FacetList.h"
 #include "polymake/hash_map"
 #include "polymake/Graph.h"
 #include "polymake/common/labels.h"
 
 namespace polymake { namespace polytope {
 
+template <typename Scalar>
 BigObject facet(BigObject p_in, Int facet_number, OptionSet options)
 {
    const IncidenceMatrix<> RIF = p_in.give("RAYS_IN_FACETS");
@@ -49,7 +50,7 @@ BigObject facet(BigObject p_in, Int facet_number, OptionSet options)
          p_out.take("CONE_DIM") << dim-1;
       }
    } else {
-      const Matrix<Rational> R=p_in.give("RAYS"),
+      const Matrix<Scalar> R=p_in.give("RAYS"),
                              LS=p_in.give("LINEALITY_SPACE");
 
       p_out.take("RAYS") << R.minor(RIF[facet_number],All);
@@ -92,6 +93,8 @@ face_pair(BigObject p_in, const Set<Int>& some_rays)
    return { rays_in_facets_found, facets_containing_given_rays };
 }
 
+
+template <typename Scalar>
 BigObject face(BigObject p_in, const Set<Int>& some_rays, OptionSet options)
 {
    const IncidenceMatrix<> RIF = p_in.give("RAYS_IN_FACETS");
@@ -101,7 +104,7 @@ BigObject face(BigObject p_in, const Set<Int>& some_rays, OptionSet options)
    const Set<Int>& rays_of_face = fp.first;
    const Set<Int>& facets_containing_face = fp.second;
    Set<Int> facet_candidates = sequence(0, n_facets) - facets_containing_face; // facet indices
-   PowerSet<Int> facets_of_face;
+   FacetList facets_of_face;
    for (auto f = entire(facet_candidates); !f.at_end(); ++f)
       facets_of_face.insertMax(rays_of_face * RIF.row(*f)); // sets of ray indices
    const Int n_rays_of_face = rays_of_face.size(), n_facets_of_face = facets_of_face.size();
@@ -111,9 +114,9 @@ BigObject face(BigObject p_in, const Set<Int>& some_rays, OptionSet options)
    for (auto v = entire(rays_of_face); !v.at_end(); ++v)
       relabel[*v]=idx++;
 
-   IncidenceMatrix<> rif_face(n_facets_of_face,n_rays_of_face);
+   IncidenceMatrix<> rif_face(n_facets_of_face, n_rays_of_face);
    idx = 0;
-   for (auto f = entire(facets_of_face); !f.at_end(); ++f, ++idx)
+   for (auto f = entire(lex_ordered(facets_of_face)); !f.at_end(); ++f, ++idx)
       for (auto v = entire(*f); !v.at_end(); ++v)
          rif_face(idx,relabel[*v])=1;
    
@@ -121,8 +124,8 @@ BigObject face(BigObject p_in, const Set<Int>& some_rays, OptionSet options)
    p_out.take("RAYS_IN_FACETS") << rif_face;
 
    if (!options["no_coordinates"]) {
-      const Matrix<Rational> R=p_in.give("RAYS"),
-                             LS=p_in.give("LINEALITY_SPACE");
+      const Matrix<Scalar> R=p_in.give("RAYS"),
+                          LS=p_in.give("LINEALITY_SPACE");
 
       p_out.take("RAYS") << R.minor(rays_of_face,All);
       p_out.take("LINEALITY_SPACE") << LS;
@@ -137,7 +140,7 @@ BigObject face(BigObject p_in, const Set<Int>& some_rays, OptionSet options)
    return p_out;
 }
 
-UserFunction4perl("# @category Producing a polytope from polytopes"
+UserFunctionTemplate4perl("# @category Producing a polytope from polytopes"
                   "# Extract the given //facet// of a polyhedron and write it as a new polyhedron."
                   "# @param Cone P"
                   "# @param Int facet"
@@ -146,7 +149,7 @@ UserFunction4perl("# @category Producing a polytope from polytopes"
                   "# @return Cone"
                   "# @example To create a cone from the vertices of the zeroth facet of the 3-cube, type this:"
                   "# > $p = facet(cube(3),0);",
-                  &facet,"facet(Cone $ {no_coordinates => 0, no_labels => 0})");
+                  "facet<Scalar>(Cone<Scalar> $ {no_coordinates => 0, no_labels => 0})");
 
 UserFunction4perl("# @category Other"
                   "# For a given set S of rays compute the smallest face F of a cone P containing them all; see also //face//."
@@ -159,7 +162,7 @@ UserFunction4perl("# @category Other"
                   "# | 1",
                   &face_pair,"face_pair(Cone $)");
 
-UserFunction4perl("# @category Producing a polytope from polytopes"
+UserFunctionTemplate4perl("# @category Producing a polytope from polytopes"
                   "# For a given set S of rays compute the smallest face F of a cone P containing them all; see also //face_pair//."
                   "# @param Cone P"
                   "# @param Set S"
@@ -168,7 +171,7 @@ UserFunction4perl("# @category Producing a polytope from polytopes"
                   "# @return Cone"
                   "# @example To create a cone from the vertices of the zeroth facet of the 3-cube, type this:"
                   "# > $p = face(cube(3),[0,1]);",
-                  &face,"face(Cone $ {no_coordinates => 0, no_labels => 0})");
+                  "face<Scalar>(Cone<Scalar> $ {no_coordinates => 0, no_labels => 0})");
 
 } }
 
