@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -22,13 +23,13 @@
 namespace polymake { namespace polytope {
 
 template <typename Coord>
-void rel_int_point(perl::Object p)
+void rel_int_point(BigObject p)
 {
    std::string f;
    Matrix<Coord> F=p.give_with_property_name("FACETS | INEQUALITIES",f);
    Matrix<Coord>  E;
    const Vector<Coord> v0=p.give("ONE_VERTEX");      
-   int n = v0.dim()-1;
+   Int n = v0.dim()-1;
    bool unbounded = !p.give("BOUNDED");
 
    ListMatrix<Vector <Coord> > verts(0,n); //the linear space corresponding to the affine space spanned by the vertices
@@ -47,34 +48,34 @@ void rel_int_point(perl::Object p)
 
       
    if (unbounded) {
-      const Vector<Coord> VEC1=-v0.slice(1)+ones_vector<Coord>(n);
-      const Vector<Coord> VEC2=v0.slice(1)+ones_vector<Coord>(n);
+      const Vector<Coord> VEC1 = -v0.slice(range_from(1)) + ones_vector<Coord>(n);
+      const Vector<Coord> VEC2 = v0.slice(range_from(1)) + ones_vector<Coord>(n);
       F/=(VEC1|unit_matrix<Coord>(n))/(VEC2|-unit_matrix<Coord>(n));
    }
   
-   int n_verts,n_equats; 
-   while ((n_verts=verts.rows())+(n_equats=equats.rows())<n) {
-      Matrix<Coord> ort=null_space(verts);
+   Int n_verts, n_equats; 
+   while ((n_verts = verts.rows()) + (n_equats = equats.rows()) < n) {
+      Matrix<Coord> ort = null_space(verts);
 
       bool dep=true;      
       
       Matrix <Coord> A(0,n);
-      if (equats.cols()!=0) { A = dehomogenize(equats); };
+      if (equats.cols() != 0) A = dehomogenize(equats);
       //we try to find a vector orthogonal to the space of vertices and not yet contained in equats
-      int i=0;
-      for (; dep;++i) {
-         if (rank(A/ort.row(i))==n_equats+1) dep=false;
+      Int i=0;
+      for (; dep; ++i) {
+         if (rank(A/ort.row(i))==n_equats+1) dep = false;
       }
-      i--;
+      --i;
       //we solve the linear program for this direction
-      perl::Object p_new(p.type());
+      BigObject p_new(p.type());
 
       // this should be improved...
       if (unbounded) {
          if (ah_eq)
             // we need to take care of the restriction that AFFINE_HULL may only be written if F contains the FACETS
             p_new.take( f=="FACETS" ? Str("AFFINE_HULL") : Str("EQUATIONS") ) << E;
-         p_new.take(f)<<F;
+         p_new.take(f) << F;
       } else {
          if (ah_eq)
             p_new.take("EQUATIONS") << E;
@@ -98,22 +99,22 @@ void rel_int_point(perl::Object p)
          equats/=(-min|ort.row(i));
       //else we get a new vertex
       else {
-         const Vector<Coord> M=p_new.give("LP.MINIMAL_VERTEX");
-         const Matrix<Coord> Mat=verts/(M-v0).slice(1);
+         const Vector<Coord> M = p_new.give("LP.MINIMAL_VERTEX");
+         const Matrix<Coord> Mat = verts / (M-v0).slice(range_from(1));
          if (rank(Mat)==n_verts+1)
-            verts/=(M-v0).slice(1);
+            verts /= (M-v0).slice(range_from(1));
          else {
             const Vector<Coord> M2=p_new.give("LP.MAXIMAL_VERTEX");
-            verts/=(M2-v0).slice(1);
+            verts /= (M2-v0).slice(range_from(1));
          }
       }
    }
 
-   p.take("CONE_DIM")<<verts.rows()+1;
+   p.take("CONE_DIM") << verts.rows()+1;
    p.take("REL_INT_POINT") << (v0+(0|average(rows(verts/zero_vector<Coord>(n)))));
 }
 
-FunctionTemplate4perl("rel_int_point<Coords>(Polytope<Coords>) : void");
+FunctionTemplate4perl("rel_int_point<Coords>(Polytope<Coords>)");
 } }
 
 // Local Variables:
