@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -92,7 +92,7 @@ BigObject truncation(BigObject p_in, const GenericSet<TSet>& trunc_vertices, Opt
       copy_range(entire(rows(VIF.minor(All,~keys(vertex_map)))), rows(VIF_out).begin());
 
    Int new_facet = n_facets;
-   for (const auto vm : vertex_map) {
+   for (const auto& vm : vertex_map) {
       Int new_vertex = vm.second;
       for (auto nb = entire(G.adjacent_nodes(vm.first));  !nb.at_end();  ++nb, ++new_vertex) {
          // the new vertex inherits the ridge from the truncated vertex,
@@ -146,7 +146,7 @@ BigObject truncation(BigObject p_in, const GenericSet<TSet>& trunc_vertices, Opt
       if (orth.cols() != 0) orth.col(0).fill(0);
 
       auto new_facet_it = rows(F_out).begin() + n_facets;
-      for (const auto vm : vertex_map) {
+      for (const auto& vm : vertex_map) {
          const Int v_cut_off = vm.first;
          Matrix<Scalar> basis(G.out_degree(v_cut_off), V.cols());
          const bool simple_vertex = basis.rows()+AH.rows() == V.cols()-1;
@@ -237,7 +237,7 @@ template<typename Scalar>
 BigObject truncation(BigObject p_in, const pm::all_selector&, OptionSet options)
 {
    const Int n_verts = p_in.give("N_VERTICES");
-   BigObject p_out=truncation<Scalar>(p_in,sequence(0,n_verts),options);
+   BigObject p_out = truncation<Scalar>(p_in, sequence(0, n_verts), options);
    p_out.set_description() << p_in.name() << " with all vertices truncated" << endl;
    return p_out;
 }
@@ -245,7 +245,7 @@ BigObject truncation(BigObject p_in, const pm::all_selector&, OptionSet options)
 template<typename Scalar>
 BigObject truncation(BigObject p_in, Int vertex, OptionSet options)
 {
-   BigObject p_out=truncation<Scalar>(p_in, scalar2set(vertex), options);
+   BigObject p_out = truncation<Scalar>(p_in, scalar2set(vertex), options);
    p_out.set_description() << p_in.name() << " with vertex " << vertex << " truncated" << endl;
    return p_out;
 }
