@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -67,7 +67,7 @@ UserFunctionTemplate4perl("# @category Geometry"
                           "# @param Polytope P the zonotope"
                           "# @option Bool lattice_origin_is_vertex true if the origin of the tiling lattice should be a vertex of P; default false, ie, the origin will be the barycenter of P"
                           "# @return AffineLattice"
-                          "# @example [prefer cdd] This determines a tiling lattice for a parallelogram with the origin as its vertex barycenter and prints it base vectors:"
+                          "# @example [prefer cdd] [require bundled:cdd] This determines a tiling lattice for a parallelogram with the origin as its vertex barycenter and prints it base vectors:"
                           "# > $M = new Matrix([[1,1,0],[1,1,1]]);"
                           "# > $p = zonotope($M);"
                           "# > $A = zonotope_tiling_lattice($p);"
