@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -14,14 +15,15 @@
 --------------------------------------------------------------------------------
 */
 
+#pragma once
 #include "polymake/GenericStruct.h"
 
 namespace polymake { namespace topaz {
 
 struct IntersectionForm : GenericStruct<IntersectionForm> {
-   DeclSTRUCT( DeclFIELD(parity,int)
-               DeclFIELD(positive,int)
-               DeclFIELD(negative,int) );
+   DeclSTRUCT( DeclFIELD(parity, Int)
+               DeclFIELD(positive, Int)
+               DeclFIELD(negative, Int) );
 };
 
 } }
