@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -21,22 +22,22 @@
 
 namespace polymake { namespace topaz {
 
-bool is_locally_strongly_connected(perl::Object p, perl::OptionSet options)
+bool is_locally_strongly_connected(BigObject p, OptionSet options)
 {
    const Lattice<BasicDecoration>& HD = p.give("HASSE_DIAGRAM");
-   const int dim = HD.rank()-2;
+   const Int dim = HD.rank()-2;
 
    const bool verbose=options["verbose"],
                   all=options["all"];
    bool loc_str_conn = true;
 
-   for (int d=0; d<dim; ++d)
-      for (auto f=entire(HD.nodes_of_rank(d+1)); !f.at_end(); ++f) {
-         const FacetList star(star_in_HD(HD,*f));
+   for (Int d = 0; d < dim; ++d)
+      for (const auto f : HD.nodes_of_rank(d+1)) {
+         const FacetList star(star_in_HD(HD, f));
 
-         if ( !graph::is_connected(dual_graph(star)) ) {
+         if (!graph::is_connected(dual_graph(star))) {
             if (verbose)
-               cout << "is_locally_strongly_connected: star(" << HD.face(*f) << ") is not strongly connected." << endl;
+               cout << "is_locally_strongly_connected: star(" << HD.face(f) << ") is not strongly connected." << endl;
             loc_str_conn = false;
             if (!all) break;
          }
