@@ -17,6 +17,12 @@
 	---
 	Copyright (C) 2011 - 2015, Simon Hampe <simon.hampe@googlemail.com>
 
+	---
+	Copyright (c) 2016-2021
+	Ewgenij Gawrilow, Michael Joswig, and the polymake team
+	Technische Universität Berlin, Germany
+	https://polymake.org
+
 	This file provides functionality to compute certain special tropical varieties
 	*/
 
@@ -26,13 +32,12 @@
 
 namespace polymake { namespace tropical {
 
-	bool is_empty_cycle(perl::Object cycle) {
-		int proj_ambient_dim = cycle.give("PROJECTIVE_AMBIENT_DIM");
-		IncidenceMatrix<> mpol = cycle.give("MAXIMAL_POLYTOPES");
-		return proj_ambient_dim < 0 || mpol.rows() == 0;
-	}//END is_empty
-
-	// PERL WRAPPER -------------------------------------------
+bool is_empty_cycle(BigObject cycle)
+{
+  Int proj_ambient_dim = cycle.give("PROJECTIVE_AMBIENT_DIM");
+  IncidenceMatrix<> mpol = cycle.give("MAXIMAL_POLYTOPES");
+  return proj_ambient_dim < 0 || mpol.rows() == 0;
+}
 
 UserFunctionTemplate4perl("# @category Creation functions for specific cycles"
 			  "# Creates the empty cycle in a given ambient dimension"
@@ -43,7 +48,7 @@ UserFunctionTemplate4perl("# @category Creation functions for specific cycles"
 			  "empty_cycle<Addition>($)");
 
 UserFunction4perl("# @category Degeneracy tests"
-		  "# This tests wheter a cycle is the empty cycle.",
+		  "# This tests whether a cycle is the empty cycle.",
 		  &is_empty_cycle,"is_empty(Cycle)");
 
 UserFunctionTemplate4perl("# @category Creation functions for specific cycles"
@@ -119,6 +124,4 @@ UserFunctionTemplate4perl("# @category Creation functions for specific cycles"
 			  "# @return Cycle<Addition> The k-skeleton of the tropical hypersurface dual to the cross"
 			  "# polytope. It is a smooth (for weight 1), irreducible (for h > 0) variety, which is invariant under reflection.",
 			  "cross_variety<Addition>($,$; $=1,$=1)");
-
-
-}}
+} }
