@@ -1,6 +1,13 @@
 # input for generate_ninja_targets.pl
 
 if ($ConfigFlags{'bundled.sympol.UseBundled'}) {
+  my $no_warnings="";
+  foreach (qw(shadow conversion zero-as-null-pointer-constant)) {
+     if ($ConfigFlags{CXXFLAGS} =~ /-W$_\b/) {
+	$no_warnings .= " -Wno-$_";
+     }
+  }
+
   ( staticlib => {
        SOURCEDIR => '${root}/bundled/sympol/external/sympol/sympol',
        SOURCES => [ qw( configuration.cpp facesuptosymmetrylist.cpp polyhedron.cpp polyhedrondatastorage.cpp polyhedronio.cpp qarray.cpp raycomputationcdd.cpp raycomputationlrs.cpp
@@ -9,8 +16,7 @@ if ($ConfigFlags{'bundled.sympol.UseBundled'}) {
                         symmetrygroupconstruction/graphconstructiondefault.cpp symmetrygroupconstruction/matrixconstruction.cpp symmetrygroupconstruction/matrixconstructiondefault.cpp ) ],
        'raycomputationcdd.cpp' => '-DGMPRATIONAL ${bundled.cdd.CFLAGS}',
        'raycomputationlrs.cpp' => '-DGMP -DMA ${bundled.lrs.CFLAGS}',
-       $ConfigFlags{ExternalHeaders} =~ /\bpermlib\b/
-       ? ( CXXFLAGS => '-I${root}/include/external/permlib' ) : (),
+       CXXFLAGS => $no_warnings . ($ConfigFlags{ExternalHeaders} =~ /\bpermlib\b/ ? ' -I${root}/include/external/permlib' : ''),
     },
   )
 } else {
