@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2017
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -14,12 +15,11 @@
 --------------------------------------------------------------------------------
 */
 
+#pragma once
 /** @file GenericGraph.h
     @brief Implementation of pm::GenericGraph class
 */
 
-#ifndef POLYMAKE_GENERIC_GRAPH_H
-#define POLYMAKE_GENERIC_GRAPH_H
 
 #include "polymake/GenericIncidenceMatrix.h"
 #include "polymake/GenericMatrix.h"
@@ -74,7 +74,7 @@ class uniq_edge_list
                                             IteratorConstructorTag< input_truncator_constructor >,
                                             OperationTag< BuildUnaryIt<uniq_edge_predicate> > > > {
 public:
-   int dim() const { return this->hidden().dim(); }
+   Int dim() const { return this->hidden().dim(); }
 };
 
 template <typename TGraph, bool directed=TGraph::is_directed,
@@ -83,13 +83,19 @@ struct edge_container_impl;
 
 } // end namespace pm::graph
 
+template <typename TGraph, typename dir_val=typename TGraph::dir>
+class GenericGraph;
+
+template <typename T, typename... Dir>
+using is_generic_graph = is_derived_from_instance_of<pure_type_t<T>, GenericGraph, Dir...>;
+
 /** @class GenericGraph
     @brief @ref generic "Generic type" for all graph classes.
 
     Defines various types and constants.
 */
 
-template <typename TGraph, typename dir_val=typename TGraph::dir>
+template <typename TGraph, typename dir_val>
 class GenericGraph
    : public Generic<TGraph> {
 protected:
@@ -97,19 +103,19 @@ protected:
    GenericGraph(const GenericGraph&) {}
 
 public:
-   typedef dir_val dir;
-   static const bool is_directed=dir::value==graph::Directed::value;
-   static const bool is_multigraph=dir::multigraph;
-   typedef GenericGraph generic_type;
-   typedef graph::Graph<dir> persistent_type;
-   typedef typename Generic<TGraph>::top_type top_type;
+   using dir = dir_val;
+   static constexpr bool is_directed = dir::value == graph::Directed::value;
+   static constexpr bool is_multigraph = dir::multigraph;
+   using generic_type = GenericGraph;
+   using persistent_type = graph::Graph<dir>;
+   using typename Generic<TGraph>::top_type;
 
    template <typename Result>
    struct rebind_generic {
       typedef GenericGraph<Result, dir> type;
    };
 
-   int nodes() const
+   Int nodes() const
    {
       AssertOVERLOADED(GenericGraph, top_type, nodes);
       return this->top().nodes();
@@ -123,7 +129,7 @@ public:
    top_type& operator+= (const GenericGraph<TGraph2>& g2)
    {
       static_assert(!is_multigraph, "in-place modification of a multigraph is not defined");
-      if (POLYMAKE_DEBUG || !Unwary<TGraph>::value || !Unwary<TGraph2>::value) {
+      if (POLYMAKE_DEBUG || is_wary<TGraph>() || is_wary<TGraph2>()) {
          if (this->top().nodes() != g2.top().nodes())
             throw std::runtime_error("GenericGraph::operator+= - dimension mismatch");
          if (this->top().has_gaps() || g2.top().has_gaps())
@@ -137,7 +143,7 @@ public:
    top_type& operator-= (const GenericGraph<TGraph2>& g2)
    {
       static_assert(!is_multigraph, "in-place modification of a multigraph is not defined");
-      if (POLYMAKE_DEBUG || !Unwary<TGraph>::value || !Unwary<TGraph2>::value) {
+      if (POLYMAKE_DEBUG || is_wary<TGraph>() || is_wary<TGraph2>()) {
          if (this->top().nodes() != g2.top().nodes())
             throw std::runtime_error("GenericGraph::operator-= - dimension mismatch");
          if (this->top().has_gaps() || g2.top().has_gaps())
@@ -151,7 +157,7 @@ public:
    top_type& operator*= (const GenericGraph<TGraph2>& g2)
    {
       static_assert(!is_multigraph, "in-place modification of a multigraph is not defined");
-      if (POLYMAKE_DEBUG || !Unwary<TGraph>::value || !Unwary<TGraph2>::value) {
+      if (POLYMAKE_DEBUG || is_wary<TGraph>() || is_wary<TGraph2>()) {
          if (this->top().nodes() != g2.top().nodes())
             throw std::runtime_error("GenericGraph::operator*= - dimension mismatch");
          if (this->top().has_gaps() || g2.top().has_gaps())
@@ -165,7 +171,7 @@ public:
    top_type& operator^= (const GenericGraph<TGraph2>& g2)
    {
       static_assert(!is_multigraph, "in-place modification of a multigraph is not defined");
-      if (POLYMAKE_DEBUG || !Unwary<TGraph>::value || !Unwary<TGraph2>::value) {
+      if (POLYMAKE_DEBUG || is_wary<TGraph>() || is_wary<TGraph2>()) {
          if (this->top().nodes() != g2.top().nodes())
             throw std::runtime_error("GenericGraph::operator^= - dimension mismatch");
          if (this->top().has_gaps() || g2.top().has_gaps())
@@ -176,12 +182,12 @@ public:
    }
 
    template <typename TGraph2>
-   using graph_overlay_t = graph::Graph<typename std::conditional<dir::value==TGraph2::dir::value, dir, graph::Directed>::type>;
+   using graph_overlay_t = graph::Graph<std::conditional_t<dir::value==TGraph2::dir::value, dir, graph::Directed>>;
 
    template <typename TGraph2>
    graph_overlay_t<TGraph2> operator+ (const GenericGraph<TGraph2>& g2) const
    {
-      if (POLYMAKE_DEBUG || !Unwary<TGraph>::value || !Unwary<TGraph2>::value) {
+      if (POLYMAKE_DEBUG || is_wary<TGraph>() || is_wary<TGraph2>()) {
          if (this->top().nodes() != g2.top().nodes())
             throw std::runtime_error("GenericGraph::operator+ - dimension mismatch");
          if (this->top().has_gaps() || g2.top().has_gaps())
@@ -194,7 +200,7 @@ public:
    graph::Graph<typename dir::non_multi_type>
    operator- (const GenericGraph<TGraph2>& g2) const
    {
-      if (POLYMAKE_DEBUG || !Unwary<TGraph>::value || !Unwary<TGraph2>::value) {
+      if (POLYMAKE_DEBUG || is_wary<TGraph>() || is_wary<TGraph2>()) {
          if (this->top().nodes() != g2.top().nodes())
             throw std::runtime_error("GenericGraph::operator- - dimension mismatch");
          if (this->top().has_gaps() || g2.top().has_gaps())
@@ -206,7 +212,7 @@ public:
    template <typename TGraph2>
    graph_overlay_t<TGraph2> operator* (const GenericGraph<TGraph2>& g2) const
    {
-      if (POLYMAKE_DEBUG || !Unwary<TGraph>::value || !Unwary<TGraph2>::value) {
+      if (POLYMAKE_DEBUG || is_wary<TGraph>() || is_wary<TGraph2>()) {
          if (this->top().nodes() != g2.top().nodes())
             throw std::runtime_error("GenericGraph::operator* - dimension mismatch");
          if (this->top().has_gaps() || g2.top().has_gaps())
@@ -218,7 +224,7 @@ public:
    template <typename TGraph2>
    graph_overlay_t<TGraph2> operator^ (const GenericGraph<TGraph2>& g2) const
    {
-      if (POLYMAKE_DEBUG || !Unwary<TGraph>::value || !Unwary<TGraph2>::value) {
+      if (POLYMAKE_DEBUG || is_wary<TGraph>() || is_wary<TGraph2>()) {
          if (this->top().nodes() != g2.top().nodes())
             throw std::runtime_error("GenericGraph::operator^ - dimension mismatch");
          if (this->top().has_gaps() || g2.top().has_gaps())
@@ -230,7 +236,7 @@ public:
    graph::Graph<typename dir::non_multi_type>
    operator~ () const
    {
-      if (POLYMAKE_DEBUG || !Unwary<TGraph>::value) {
+      if (POLYMAKE_DEBUG || is_wary<TGraph>()) {
          if (this->top().has_gaps())
             throw std::runtime_error("GenericGraph::operator~ - not supported for graphs with deleted nodes");
       }
@@ -259,9 +265,9 @@ public:
 template <typename TGraph>
 class Nodes
    : public redirected_container< Nodes<TGraph>,
-                                  mlist< ContainerTag< typename TGraph::node_container_ref >,
+                                  mlist< ContainerRefTag< typename TGraph::node_container_ref >,
                                          MasqueradedTop > >
-   , public GenericSet<Nodes<TGraph>, int, operations::cmp> {
+   , public GenericSet<Nodes<TGraph>, Int, operations::cmp> {
 protected:
    Nodes();
    ~Nodes();
@@ -288,8 +294,8 @@ protected:
    ~Edges();
 public:
    using graph::edge_container_impl<TGraph>::get_container;
-   int size() const { return this->hidden().edges(); }
-   int max_size() const { return size(); }
+   Int size() const { return this->hidden().edges(); }
+   Int max_size() const { return size(); }
 };
 
 namespace graph {
@@ -315,7 +321,7 @@ struct edge_container_impl<TGraph, false, true> {
    class container
       : public modified_container_impl< container,
                                         mlist< HiddenTag< TGraph >,
-                                               ContainerTag< typename base_t::container_ref >,
+                                               ContainerRefTag< typename base_t::container_ref >,
                                                OperationTag< operations::masquerade<uniq_edge_list> > > >
       , public edge_container_access<container, TGraph> {
    public:
@@ -334,7 +340,7 @@ struct edge_container_impl<TGraph, false, false> {
    class container
       : public modified_container_impl< container,
                                         mlist< HiddenTag< TGraph >,
-                                               ContainerTag< typename base_t::container_ref >,
+                                               ContainerRefTag< typename base_t::container_ref >,
                                                OperationTag< operation > > >
       , public edge_container_access<container, TGraph> {
    public:
@@ -344,7 +350,7 @@ struct edge_container_impl<TGraph, false, false> {
    class const_container
       : public modified_container_impl< const_container,
                                         mlist< HiddenTag< TGraph >,
-                                               ContainerTag< typename base_t::const_container_ref >,
+                                               ContainerRefTag< typename base_t::const_container_ref >,
                                                OperationTag< operation > > >
       , public edge_container_access<const_container, TGraph> {
    public:
@@ -377,14 +383,14 @@ public:
 
 template <typename TGraph>
 class AdjacencyMatrix<TGraph, true>
-   : public GenericMatrix< AdjacencyMatrix<TGraph, true>, int > {
+   : public GenericMatrix<AdjacencyMatrix<TGraph, true>, Int> {
 protected:
    AdjacencyMatrix();
    ~AdjacencyMatrix();
 public:
-   typedef int value_type;
-   typedef int reference;
-   typedef const int const_reference;
+   typedef Int value_type;
+   typedef Int reference;
+   typedef const Int const_reference;
 
    TGraph& hidden() { return reinterpret_cast<TGraph&>(*this); }
    const TGraph& hidden() const { return reinterpret_cast<const TGraph&>(*this); }
@@ -401,7 +407,7 @@ struct check_container_feature< AdjacencyMatrix<TGraph, true>, pure_sparse >
 template <typename TGraph>
 class matrix_random_access_methods< AdjacencyMatrix<TGraph, false> > {
 public:
-   bool operator() (int i, int j) const
+   bool operator() (Int i, Int j) const
    {
       return static_cast<const AdjacencyMatrix<TGraph>&>(*this).hidden().edge_exists(i,j);
    }
@@ -410,7 +416,7 @@ public:
 template <typename TGraph>
 class matrix_random_access_methods< AdjacencyMatrix<TGraph, true> > {
 public:
-   int operator() (int i, int j) const
+   Int operator() (Int i, Int j) const
    {
       return count_it(static_cast<const AdjacencyMatrix<TGraph>&>(*this).hidden().all_edges(i,j));
    }
@@ -419,7 +425,7 @@ public:
 template <typename TGraph, bool TMultigraph>
 class Rows< AdjacencyMatrix<TGraph, TMultigraph> >
    : public redirected_container< Rows< AdjacencyMatrix<TGraph, TMultigraph> >,
-                                  mlist< ContainerTag< typename TGraph::adjacency_rows_container_ref >,
+                                  mlist< ContainerRefTag< typename TGraph::adjacency_rows_container_ref >,
                                          HiddenTag< TGraph > > > {
 public:
    typename TGraph::adjacency_rows_container_ref get_container()
@@ -431,7 +437,7 @@ public:
       return this->hidden().template pretend<typename TGraph::const_adjacency_rows_container_ref>();
    }
 
-   int dim() const { return this->hidden().dim(); }
+   Int dim() const { return this->hidden().dim(); }
 
    bool prefer_sparse_representation() const
    {
@@ -442,7 +448,7 @@ public:
 template <typename TGraph, bool TMultigraph>
 class Cols< AdjacencyMatrix<TGraph, TMultigraph> >
    : public redirected_container< Cols< AdjacencyMatrix<TGraph, TMultigraph> >,
-                                  mlist< ContainerTag< typename TGraph::adjacency_cols_container >,
+                                  mlist< ContainerRefTag< typename TGraph::adjacency_cols_container_ref >,
                                          HiddenTag< TGraph > > > {
 public:
    typename TGraph::adjacency_cols_container_ref get_container()
@@ -454,7 +460,7 @@ public:
       return this->hidden().template pretend<typename TGraph::const_adjacency_cols_container_ref>();
    }
 
-   int dim() const { return this->hidden().dim(); }
+   Int dim() const { return this->hidden().dim(); }
 
    bool prefer_sparse_representation() const
    {
@@ -577,97 +583,97 @@ template <typename TGraph, bool TMultigraph>
 struct spec_object_traits< AdjacencyMatrix<TGraph, TMultigraph> >
    : spec_object_traits<is_container> {
    typedef TGraph masquerade_for;
-   static const bool is_always_const=object_traits<TGraph>::is_always_const || TMultigraph;
-   static const int is_resizeable=object_traits<TGraph>::is_resizeable;
+   static constexpr bool is_always_const = object_traits<TGraph>::is_always_const || TMultigraph;
+   static constexpr int is_resizeable = object_traits<TGraph>::is_resizeable;
 };
 
 template <typename TGraph>
 class WaryGraph : public GenericGraph<Wary<TGraph>, typename TGraph::dir> {
 public:
-   int out_degree(int n) const
+   Int out_degree(Int n) const
    {
       if (this->top().invalid_node(n))
          throw std::runtime_error("Graph::out_degree - node id out of range or deleted");
       return this->top().out_degree(n);
    }
-   int in_degree(int n) const
+   Int in_degree(Int n) const
    {
       if (this->top().invalid_node(n))
          throw std::runtime_error("Graph::in_degree - node id out of range or deleted");
       return this->top().in_degree(n);
    }
-   int degree(int n) const
+   Int degree(Int n) const
    {
       if (this->top().invalid_node(n))
          throw std::runtime_error("Graph::degree - node id out of range or deleted");
       return this->top().degree(n);
    }
 
-   bool node_exists(int n) const
+   bool node_exists(Int n) const
    {
       if (this->top().node_out_of_range(n))
          throw std::runtime_error("Graph::node_exists - node id out of range");
       return this->top().node_exists(n);
    }
-   void delete_node(int n)
+   void delete_node(Int n)
    {
       if (this->top().invalid_node(n))
          throw std::runtime_error("Graph::delete_node - node id out of range or already deleted");
       this->top().delete_node(n);
    }
 
-   int edge(int n1, int n2)
+   Int edge(Int n1, Int n2)
    {
       if (this->top().invalid_node(n1) || this->top().invalid_node(n2))
          throw std::runtime_error("Graph::edge - node id out of range or deleted");
       return this->top().edge(n1,n2);
    }
-   int edge(int n1, int n2) const
+   Int edge(Int n1, Int n2) const
    {
       if (this->top().invalid_node(n1) || this->top().invalid_node(n2))
          throw std::runtime_error("Graph::edge - node id out of range or deleted");
       return this->top().edge(n1,n2);
    }
-   int add_edge(int n1, int n2)
+   Int add_edge(Int n1, Int n2)
    {
       if (this->top().invalid_node(n1) || this->top().invalid_node(n2))
          throw std::runtime_error("Graph::add_edge - node id out of range or deleted");
       return this->top().add_edge(n1,n2);
    }
 
-   bool edge_exists(int n1, int n2) const
+   bool edge_exists(Int n1, Int n2) const
    {
       if (this->top().invalid_node(n1) || this->top().invalid_node(n2))
          throw std::runtime_error("Graph::edge_exists - node id out of range or deleted");
       return this->top().edge_exists(n1,n2);
    }
-   typename TGraph::parallel_edge_iterator all_edges(int n1, int n2)
+   typename TGraph::parallel_edge_iterator all_edges(Int n1, Int n2)
    {
       if (this->top().invalid_node(n1) || this->top().invalid_node(n2))
          throw std::runtime_error("Graph::all_edges - node id out of range or deleted");
       return this->top().all_edges(n1,n2);
    }
-   typename TGraph::parallel_edge_const_iterator all_edges(int n1, int n2) const
+   typename TGraph::parallel_edge_const_iterator all_edges(Int n1, Int n2) const
    {
       if (this->top().invalid_node(n1) || this->top().invalid_node(n2))
          throw std::runtime_error("Graph::all_edges - node id out of range or deleted");
       return this->top().all_edges(n1,n2);
    }
 
-   void delete_edge(int n1, int n2)
+   void delete_edge(Int n1, Int n2)
    {
       if (this->top().invalid_node(n1) || this->top().invalid_node(n2))
          throw std::runtime_error("Graph::delete_edge - node id out of range or deleted");
       this->top().delete_edge(n1,n2);
    }
-   void delete_all_edges(int n1, int n2)
+   void delete_all_edges(Int n1, Int n2)
    {
       if (this->top().invalid_node(n1) || this->top().invalid_node(n2))
          throw std::runtime_error("Graph::delete_all_edges - node id out of range or deleted");
       this->top().delete_all_edges(n1,n2);
    }
 
-   void contract_edge(int n1, int n2)
+   void contract_edge(Int n1, Int n2)
    {
       if (this->top().invalid_node(n1) || this->top().invalid_node(n2))
          throw std::runtime_error("Graph::contract_edge - node id out of range or deleted");
@@ -676,63 +682,63 @@ public:
       this->top().contract_edge(n1,n2);
    }
 
-   typename TGraph::out_edge_list_ref out_edges(int n)
+   typename TGraph::out_edge_list_ref out_edges(Int n)
    {
       if (this->top().invalid_node(n))
          throw std::runtime_error("Graph::out_edges - node id out of range or deleted");
       return this->top().out_edges(n);
    }
-   typename TGraph::const_out_edge_list_ref out_edges(int n) const
+   typename TGraph::const_out_edge_list_ref out_edges(Int n) const
    {
       if (this->top().invalid_node(n))
          throw std::runtime_error("Graph::out_edges - node id out of range or deleted");
       return this->top().out_edges(n);
    }
 
-   typename TGraph::in_edge_list_ref in_edges(int n)
+   typename TGraph::in_edge_list_ref in_edges(Int n)
    {
       if (this->top().invalid_node(n))
          throw std::runtime_error("Graph::in_edges - node id out of range or deleted");
       return this->top().in_edges(n);
    }
-   typename TGraph::const_in_edge_list_ref in_edges(int n) const
+   typename TGraph::const_in_edge_list_ref in_edges(Int n) const
    {
       if (this->top().invalid_node(n))
          throw std::runtime_error("Graph::in_edges - node id out of range or deleted");
       return this->top().in_edges(n);
    }
 
-   typename TGraph::out_adjacent_node_list_ref out_adjacent_nodes(int n)
+   typename TGraph::out_adjacent_node_list_ref out_adjacent_nodes(Int n)
    {
       if (this->top().invalid_node(n))
          throw std::runtime_error("Graph::out_adjacent_nodes - node id out of range or deleted");
       return this->top().out_adjacent_nodes(n);
    }
-   typename TGraph::const_out_adjacent_node_list_ref out_adjacent_nodes(int n) const
+   typename TGraph::const_out_adjacent_node_list_ref out_adjacent_nodes(Int n) const
    {
       if (this->top().invalid_node(n))
          throw std::runtime_error("Graph::out_adjacent_nodes - node id out of range or deleted");
       return this->top().out_adjacent_nodes(n);
    }
-   typename TGraph::in_adjacent_node_list_ref in_adjacent_nodes(int n)
+   typename TGraph::in_adjacent_node_list_ref in_adjacent_nodes(Int n)
    {
       if (this->top().invalid_node(n))
          throw std::runtime_error("Graph::in_adjacent_nodes - node id out of range or deleted");
       return this->top().in_adjacent_nodes(n);
    }
-   typename TGraph::const_in_adjacent_node_list_ref in_adjacent_nodes(int n) const
+   typename TGraph::const_in_adjacent_node_list_ref in_adjacent_nodes(Int n) const
    {
       if (this->top().invalid_node(n))
          throw std::runtime_error("Graph::in_adjacent_nodes - node id out of range or deleted");
       return this->top().in_adjacent_nodes(n);
    }
-   typename TGraph::adjacent_node_list_ref adjacent_nodes(int n)
+   typename TGraph::adjacent_node_list_ref adjacent_nodes(Int n)
    {
       if (this->top().invalid_node(n))
          throw std::runtime_error("Graph::adjacent_nodes - node id out of range or deleted");
       return this->top().adjacent_nodes(n);
    }
-   typename TGraph::const_adjacent_node_list_ref adjacent_nodes(int n) const
+   typename TGraph::const_adjacent_node_list_ref adjacent_nodes(Int n) const
    {
       if (this->top().invalid_node(n))
          throw std::runtime_error("Graph::adjacent_nodes - node id out of range or deleted");
@@ -740,7 +746,7 @@ public:
    }
 
    template <typename TPerm>
-   typename std::enable_if<isomorphic_to_container_of<TPerm, int>::value>::type
+   typename std::enable_if<isomorphic_to_container_of<TPerm, Int>::value>::type
    permute_nodes(const TPerm& perm)
    {
       if (perm.size() != this->top().dim())
@@ -755,13 +761,15 @@ class generic_of_GraphComponents {};
 template <typename GraphRef, template <typename> class Iterator>
 class GraphComponents : public generic_of_GraphComponents<GraphRef, Iterator> {
 protected:
-   alias<GraphRef> graph;
+   using alias_t = alias<GraphRef>;
+   alias_t graph;
 public:
-   typedef typename alias<GraphRef>::arg_type arg_type;
-   typedef typename deref<GraphRef>::type graph_t;
-   typename alias<GraphRef>::const_reference get_graph() const { return *graph; }
+   using graph_t = typename deref<GraphRef>::type;
+   decltype(auto) get_graph() const { return *graph; }
 
-   GraphComponents(arg_type G) : graph(G) {}
+   template <typename Arg, typename=std::enable_if_t<std::is_constructible<alias_t, Arg>::value>>
+   explicit GraphComponents(Arg&& graph_arg)
+      : graph(std::forward<Arg>(graph_arg)) {}
 
    typedef Iterator<graph_t> iterator;
    typedef iterator const_iterator;
@@ -772,8 +780,8 @@ public:
    iterator begin() const { return get_graph(); }
    iterator end() const { return iterator(); }
    reference front() const { return *begin(); }
-   int size() const { return count_it(begin()); }
-   bool empty() const { return get_graph().nodes()==0; }
+   Int size() const { return count_it(begin()); }
+   bool empty() const { return get_graph().nodes() == 0; }
 };
 
 template <typename GraphRef, template <typename> class Iterator>
@@ -795,7 +803,6 @@ namespace polymake {
    using pm::AdjacencyMatrix;
 }
 
-#endif // POLYMAKE_GENERIC_GRAPH_H
 
 // Local Variables:
 // mode:C++
