@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -15,8 +15,7 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_INTERNAL_CHARBUFFER_H
-#define POLYMAKE_INTERNAL_CHARBUFFER_H
+#pragma once
 
 #include <sys/types.h>
 #include <cctype>
@@ -233,7 +232,6 @@ public:
 
 } // end namespace pm
 
-#endif // POLYMAKE_INTERNAL_CHARBUFFER_H
 
 // Local Variables:
 // mode:C++
