@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -15,8 +15,7 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_INTERNAL_COMB_ARRAY_H
-#define POLYMAKE_INTERNAL_COMB_ARRAY_H
+#pragma once
 
 #include "polymake/list"
 #include "polymake/SelectedSubset.h"
@@ -494,7 +493,6 @@ namespace polymake {
    using pm::CombArray;
 }
 
-#endif // POLYMAKE_INTERNAL_COMB_ARRAY_H
 
 // Local Variables:
 // mode:C++
