@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -15,8 +15,7 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_INTERNAL_COMPARATORS_OPS_H
-#define POLYMAKE_INTERNAL_COMPARATORS_OPS_H
+#pragma once
 
 #include <cmath>
 #include <cstdlib>
@@ -346,7 +345,6 @@ struct binary_op_builder<operations::cmp_unordered, Iterator1, Iterator2, Refere
 
 } // end namespace pm
 
-#endif // POLYMAKE_INTERNAL_COMPARATORS_OPS_H
 
 // Local Variables:
 // mode:C++
