@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -14,33 +15,36 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_INTERNAL_EXTEND_ALGO_H
-#define POLYMAKE_INTERNAL_EXTEND_ALGO_H
+#pragma once
+
+#if !defined(__clang__) && __GNUC__ >= 9
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpessimizing-move"
+#endif
 
 namespace pm {
 
-template <typename Iterator1, typename Iterator2> inline
+template <typename Iterator1, typename Iterator2>
 void copy_range_impl(Iterator1&& src, Iterator2&& dst, std::true_type, std::false_type)
 {
    for (; !src.at_end(); ++src, ++dst) *dst=*src;
 }
 
-template <typename Iterator1, typename Iterator2> inline
+template <typename Iterator1, typename Iterator2>
 void copy_range_impl(Iterator1&& src, Iterator2&& dst, std::false_type, std::true_type)
 {
    for (; !dst.at_end(); ++src, ++dst) *dst=*src;
 }
 
-template <typename Iterator1, typename Iterator2> inline
+template <typename Iterator1, typename Iterator2>
 void copy_range_impl(Iterator1&& src, Iterator2&& dst, std::true_type, std::true_type)
 {
    for (; !src.at_end() && !dst.at_end(); ++src, ++dst) *dst=*src;
 }
 
 template <typename Iterator1, typename Iterator2,
-          typename=typename std::enable_if<check_iterator_feature<Iterator1, end_sensitive>::value ||
-                                           check_iterator_feature<Iterator2, end_sensitive>::value>::type>
-inline
+          typename=std::enable_if_t<check_iterator_feature<Iterator1, end_sensitive>::value ||
+                                    check_iterator_feature<Iterator2, end_sensitive>::value>>
 private_mutable_t<Iterator2> copy_range(Iterator1&& src, Iterator2&& dst)
 {
    private_mutable_t<Iterator2> dst_it=ensure_private_mutable(std::forward<Iterator2>(dst));
@@ -51,7 +55,7 @@ private_mutable_t<Iterator2> copy_range(Iterator1&& src, Iterator2&& dst)
 }
 
 
-template <typename Iterator1, typename Iterator2> inline
+template <typename Iterator1, typename Iterator2>
 bool equal_ranges_impl(Iterator1&& it1, Iterator2&& it2, std::true_type, std::false_type)
 {
    for (; !it1.at_end(); ++it1, ++it2)
@@ -59,7 +63,7 @@ bool equal_ranges_impl(Iterator1&& it1, Iterator2&& it2, std::true_type, std::fa
    return true;
 }
 
-template <typename Iterator1, typename Iterator2> inline
+template <typename Iterator1, typename Iterator2>
 bool equal_ranges_impl(Iterator1&& it1, Iterator2&& it2, std::false_type, std::true_type)
 {
    for (; !it2.at_end(); ++it1, ++it2)
@@ -67,7 +71,7 @@ bool equal_ranges_impl(Iterator1&& it1, Iterator2&& it2, std::false_type, std::t
    return true;
 }
 
-template <typename Iterator1, typename Iterator2> inline
+template <typename Iterator1, typename Iterator2>
 bool equal_ranges_impl(Iterator1&& it1, Iterator2&& it2, std::true_type, std::true_type)
 {
    for (; !it1.at_end() && !it2.at_end(); ++it1, ++it2)
@@ -76,9 +80,8 @@ bool equal_ranges_impl(Iterator1&& it1, Iterator2&& it2, std::true_type, std::tr
 }
 
 template <typename Iterator1, typename Iterator2,
-          typename=typename std::enable_if<check_iterator_feature<Iterator1, end_sensitive>::value ||
-                                           check_iterator_feature<Iterator2, end_sensitive>::value>::type>
-inline
+          typename=std::enable_if_t<check_iterator_feature<Iterator1, end_sensitive>::value ||
+                                    check_iterator_feature<Iterator2, end_sensitive>::value>>
 bool equal_ranges(Iterator1&& it1, Iterator2&& it2)
 {
    return equal_ranges_impl(ensure_private_mutable(std::forward<Iterator1>(it1)),
@@ -88,28 +91,27 @@ bool equal_ranges(Iterator1&& it1, Iterator2&& it2)
 }
 
 
-template <typename Iterator1, typename Iterator2> inline
+template <typename Iterator1, typename Iterator2>
 void swap_ranges_impl(Iterator1&& it1, Iterator2&& it2, std::true_type, std::false_type)
 {
    for (; !it1.at_end(); ++it1, ++it2) std::swap(*it1, *it2);
 }
 
-template <typename Iterator1, typename Iterator2> inline
+template <typename Iterator1, typename Iterator2>
 void swap_ranges_impl(Iterator1&& it1, Iterator2&& it2, std::false_type, std::true_type)
 {
    for (; !it2.at_end(); ++it1, ++it2) std::swap(*it1, *it2);
 }
 
-template <typename Iterator1, typename Iterator2> inline
+template <typename Iterator1, typename Iterator2>
 void swap_ranges_impl(Iterator1&& it1, Iterator2&& it2, std::true_type, std::true_type)
 {
    for (; !it1.at_end() && !it2.at_end(); ++it1, ++it2) std::swap(*it1, *it2);
 }
 
 template <typename Iterator1, typename Iterator2,
-          typename=typename std::enable_if<check_iterator_feature<Iterator1, end_sensitive>::value ||
-                                           check_iterator_feature<Iterator2, end_sensitive>::value>::type>
-inline
+          typename=std::enable_if_t<check_iterator_feature<Iterator1, end_sensitive>::value ||
+                                    check_iterator_feature<Iterator2, end_sensitive>::value>>
 void swap_ranges(Iterator1&& it1, Iterator2&& it2)
 {
    swap_ranges_impl(ensure_private_mutable(std::forward<Iterator1>(it1)),
@@ -120,8 +122,7 @@ void swap_ranges(Iterator1&& it1, Iterator2&& it2)
 
 
 template <typename Iterator,
-          typename=typename std::enable_if<check_iterator_feature<Iterator, end_sensitive>::value>::type>
-inline
+          typename=std::enable_if_t<check_iterator_feature<Iterator, end_sensitive>::value>>
 typename iterator_traits<Iterator>::value_type
 first_differ_in_range(Iterator&& src, const typename iterator_traits<Iterator>::value_type& from)
 {
@@ -134,8 +135,7 @@ first_differ_in_range(Iterator&& src, const typename iterator_traits<Iterator>::
 }
 
 template <typename Iterator, typename Value,
-          typename=typename std::enable_if<check_iterator_feature<Iterator, end_sensitive>::value>::type>
-inline
+          typename=std::enable_if_t<check_iterator_feature<Iterator, end_sensitive>::value>>
 void fill_range(Iterator&& dst, const Value& x)
 {
    auto&& it=ensure_private_mutable(std::forward<Iterator>(dst));
@@ -143,8 +143,7 @@ void fill_range(Iterator&& dst, const Value& x)
 }
 
 template <typename Iterator, typename Value,
-          typename=typename std::enable_if<check_iterator_feature<Iterator, end_sensitive>::value>::type>
-inline
+          typename=std::enable_if_t<check_iterator_feature<Iterator, end_sensitive>::value>>
 private_mutable_t<Iterator>
 find_in_range(Iterator&& src, const Value& x)
 {
@@ -154,8 +153,7 @@ find_in_range(Iterator&& src, const Value& x)
 }
 
 template <typename Iterator, typename Predicate,
-          typename=typename std::enable_if<check_iterator_feature<Iterator, end_sensitive>::value>::type>
-inline
+          typename=std::enable_if_t<check_iterator_feature<Iterator, end_sensitive>::value>>
 private_mutable_t<Iterator>
 find_in_range_if(Iterator&& src, const Predicate& pred_arg)
 {
@@ -168,7 +166,10 @@ find_in_range_if(Iterator&& src, const Predicate& pred_arg)
 
 } // end namespace pm
 
-#endif // POLYMAKE_INTERNAL_EXTEND_ALGO_H
+#if !defined(__clang__) && __GNUC__ >= 9
+#pragma GCC diagnostic pop
+#endif
+
 
 // Local Variables:
 // mode:C++
