@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -15,8 +15,7 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_INTERNAL_SPARSE_LINALG_H
-#define POLYMAKE_INTERNAL_SPARSE_LINALG_H
+#pragma once
 
 #include "polymake/vector"
 
@@ -29,8 +28,9 @@ det(SparseMatrix<E> M)
    const Int dim = M.rows();
    if (dim == 0) return one_value<E>();
 
-   std::vector<Int> column_permutation(dim);
+   std::vector<Int> column_permutation(dim), column_permutation_inv(dim);
    copy_range(entire(sequence(0, dim)), column_permutation.begin());
+   copy_range(entire(sequence(0, dim)), column_permutation_inv.begin());
    E result = one_value<E>();
 
    for (auto pivotrow = entire(rows(M)); !pivotrow.at_end(); ++pivotrow) {
@@ -41,8 +41,10 @@ det(SparseMatrix<E> M)
       const Int pr = pivotrow.index();
       const Int pc = pivot.index();   // row and column index
       result *= *pivot;
-      if (column_permutation[pr] != pc) {
-         std::swap(column_permutation[pr], column_permutation[pc]);
+      if (column_permutation[pc] != pr) {
+         Int i = column_permutation_inv[pr];
+         std::swap(column_permutation_inv[pr], column_permutation_inv[column_permutation[pc]]);
+         std::swap(column_permutation[i], column_permutation[pc]);
          negate(result);
       }
 
@@ -167,7 +169,6 @@ lin_solve(SparseMatrix<E> A, Vector<E> B)
 
 } // end namespace pm
 
-#endif // POLYMAKE_INTERNAL_SPARSE_LINALG_H
 
 // Local Variables:
 // mode:C++
