@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -14,8 +15,7 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_NODE_EDGE_INCIDENCES_H
-#define POLYMAKE_NODE_EDGE_INCIDENCES_H
+#pragma once
 
 #include "polymake/SparseMatrix.h"
 #include "polymake/Graph.h"
@@ -27,10 +27,10 @@ template <typename Coord, typename Graph> inline
 SparseMatrix<Coord> node_edge_incidences(const GenericGraph<Graph, graph::Directed>& G)
 {
    SparseMatrix<Coord> ne(G.top().nodes(), G.top().edges());
-   int k=0;
-   for (typename Entire< Edges<Graph> >::const_iterator e=entire(edges(G)); !e.at_end(); ++e, ++k) {
-      ne(e.to_node(),  k)=1;
-      ne(e.from_node(),k)=-1;
+   Int k = 0;
+   for (auto e = entire(edges(G)); !e.at_end(); ++e, ++k) {
+      ne(e.to_node(),   k) = 1;
+      ne(e.from_node(), k) =-1;
    }
    return ne;
 }
@@ -41,10 +41,10 @@ template <typename Coord, typename Graph> inline
 SparseMatrix<Coord> node_edge_incidences(const GenericGraph<Graph, graph::Undirected>& G)
 {
    SparseMatrix<Coord> ne(G.top().nodes(), G.top().edges());
-   int k=0;
-   for (typename Entire< Edges<Graph> >::const_iterator e=entire(edges(G)); !e.at_end(); ++e, ++k) {
-      ne(e.to_node(),  k)=1;
-      ne(e.from_node(),k)=1;
+   Int k = 0;
+   for (auto e=entire(edges(G)); !e.at_end(); ++e, ++k) {
+      ne(e.to_node(),   k) = 1;
+      ne(e.from_node(), k) = 1;
    }
    return ne;
 }
@@ -54,7 +54,6 @@ namespace polymake {
 using pm::node_edge_incidences;
 }
 
-#endif // POLYMAKE_NODE_EDGE_INCIDENCES_H
 
 // Local Variables:
 // mode:C++
