@@ -1,4 +1,4 @@
-#  Copyright (c) 1997-2020
+#  Copyright (c) 1997-2021
 #  Ewgenij Gawrilow, Michael Joswig, and the polymake team
 #  Technische Universität Berlin, Germany
 #  https://polymake.org
@@ -21,7 +21,7 @@ use feature 'state';
 
 package Polymake::Core::CPlusPlus;
 
-declare ($private_wrapper_ext, $custom_handler);
+declare ($private_wrapper_ext, %private_wrappers);
 
 # controls whether and where new cpperl glue definitions are generated:
 #   "private"   - in "wrappers" folder in user's settings area
@@ -1359,16 +1359,11 @@ use Polymake::Enum Assoc => qw( helem find exists delete_void delete_ret );
 
 use Polymake::Ext;
 
-add_custom_vars sub {
-   $custom_handler=$Custom->app_handler(__PACKAGE__);
-
-   declare %private_wrappers;
-   $custom_handler->add('%private_wrappers', <<'.', Customize::State::hidden | Customize::State::noexport);
-# Locations of the automatically generated source code of C++/perl wrappers for private use.
-.
-
-   $custom_handler->cleanup;
-   $custom_handler->end_loading;
+add_settings_callback sub {
+   my ($settings) = @_;
+   $settings->add_item('_C++::private_wrappers', \%private_wrappers,
+                       "Autogenerated C++/perl wrappers",
+                       UserSettings::Item::Flags::hidden | UserSettings::Item::Flags::no_export);
 };
 
 sub compile {
@@ -1766,7 +1761,7 @@ sub define_constructors {
 
 #######################################################################################
 sub dump_arg {
-   if (&is_object) {
+   if (is_object($_[0])) {
       if (my $proto=UNIVERSAL::can($_[0], ".type")) {
          $proto->()->full_name;
       } else {
