@@ -1,4 +1,4 @@
-#  Copyright (c) 1997-2023
+#  Copyright (c) 1997-2021
 #  Ewgenij Gawrilow, Michael Joswig, and the polymake team
 #  Technische Universität Berlin, Germany
 #  https://polymake.org
@@ -414,10 +414,9 @@ my %completers = (
       sub {
          my ($text, $ctx) = @_;
          my @proposals;
-         if ($text =~ /^ (?: (?:!)? (?'label' $hier_id_re (?:\.)?) )? $/xo) {
+         if ($text =~ /^ (?: $hier_id_re (?:\.)? )? $/xo) {
             # maybe a label
-            my $label = $+{label};
-            @proposals = grep { /^\Q$label\E/ } map { $_->full_name } map { @{$_->labels} } try_rules($ctx->obj);
+            @proposals = grep { /^\Q$text\E/ } map { $_->full_name } map { @{$_->labels} } try_rules($ctx->obj);
          }
          Rule::prepare_header_search_pattern($text);
          push @proposals, grep { /^$text/ } map { $_->header } try_rules($ctx->obj);
@@ -425,7 +424,7 @@ my %completers = (
       },
       help => sub {
          my ($text, $ctx) = @_;
-         if ($text =~ /(?:!)? ($id_re) (?: \. $id_re)* \.? \s* $/xo) {
+         if ($text =~ /($id_re) (?: \. $id_re)* \.? \s* $/xo) {
             my $label_name = $1;
             (defined($ctx->obj) ? $ctx->obj->type->application : $User::application)->help->find('preferences', $label_name)
          } else {
@@ -1477,7 +1476,7 @@ sub complete_user_variable_name {
    if ((my $pkg_end = rindex($prefix,"::")) > 0) {
       my $pkg = substr($prefix, 0, $pkg_end);
       my $symtab = eval { get_symtab("Polymake::User::$pkg") } or return;
-      map { $sigil."$pkg\::".substr($_,1) } complete_variable_name_in_pkg($symtab, $sigil, substr($prefix, $pkg_end+2));
+      map { "$pkg\::$_" } complete_variable_name_in_pkg($symtab, $sigil, substr($prefix, $pkg_end+2));
    } else {
       complete_variable_name_in_pkg(\%Polymake::User::, @_);
    }
